import { AxiosError } from 'axios'
import { useQuery as useRQ, UseQueryOptions } from 'react-query'

import { Implementation, Pattern } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace GetImplementationsByPatternIdQuery {
  export type Params = { patternId: Pattern['id'] }

  export type Response = Implementation[]

  export const key = ['pattern', 'implementations']

  export const getKey = (params: Params) => [...key, params]

  export const queryFn = (params: Params) =>
    axiosService
      .get<Response>(`/patterns/${params.patternId}/implementations`)
      .then((res) => res.data)

  export const useQuery = <Select = Response>(
    params: Params,
    options: UseQueryOptions<Response, AxiosError, Select> = {}
  ) => {
    return useRQ(getKey(params), () => queryFn(params), {
      ...options,
    })
  }
}
