import { AxiosError, toFormData } from 'axios'
import { useMutation as useRQMutation, UseMutationOptions } from 'react-query'

import { Formalization, Implementation } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace RunTestsStep2Mutation {
  export type Params = {
    id: Formalization['id']
    implementationId: Implementation['id']
    wrapperFile: File
    name: string
  }
  export type Response = { path: string }

  export const key = ['formalizations', 'run-tests-step-2']

  export const mutationFn = (params: Params) =>
    axiosService
      .post<Response>(
        `/formalizations/${params.id}/run-tests-step-2/${params.implementationId}`,
        toFormData(params)
      )
      .then((res) => res.data)

  export const useMutation = (
    options: UseMutationOptions<Response, AxiosError, Params> = {}
  ) => {
    return useRQMutation(mutationFn, { ...options, mutationKey: key })
  }
}
