import { ButtonProps, Tooltip, useDisclosure, Text } from '@chakra-ui/react'
import React from 'react'
import { Implementation, Pattern } from 'src/models'
import { RunTestsButtonModal } from './run-tests-button-modal'

export type RunTestsButtonProps = {
  implementation: Implementation
  pattern: Pattern
  hasTooltip?: boolean
  children: React.ReactElement<ButtonProps>
}

export const RunTestsButton: React.FC<RunTestsButtonProps> = ({
  implementation,
  pattern,
  hasTooltip = false,
  children,
}) => {
  const disclosure = useDisclosure()

  const btn = React.cloneElement(children, { onClick: disclosure.onOpen })

  return (
    <>
      <Tooltip isDisabled={!hasTooltip} label={<Text>Correr tests</Text>}>
        {btn}
      </Tooltip>

      {disclosure.isOpen && (
        <RunTestsButtonModal
          implementation={implementation}
          pattern={pattern}
          disclosure={disclosure}
        />
      )}
    </>
  )
}
